@@ -17,7 +17,10 @@ def perform_recaptcha_validation(g_recaptcha_response: str) -> bool:
     )
     google_recaptcha_secret_key = get_from_settings_or_raise_missing_config("GOOGLE_RECAPTCHA_SECRET_KEY")
 
-    logger.info("Checking GoogleRecaptcha")
+    min_score_threshold = float(get_from_settings_or_raise_missing_config("GOOGLE_RECAPTCHA_SCORE_THRESHOLD", "0.8"))
+
+    logger.debug("Performing request to Google to check if recaptcha is valid")
+
 
     data = {"response": g_recaptcha_response, "secret": google_recaptcha_secret_key}
 
@@ -26,7 +29,16 @@ def perform_recaptcha_validation(g_recaptcha_response: str) -> bool:
     
     result_json = resp.json()
 
-    if not result_json.get("success"):
-        logger.info(f"GoogleRecaptcha failed! Input: {g_recaptcha_response} Output: {result_json}")
+    logger.info(f"Status code: {resp.status_code}; min_score_threshold: {min_score_threshold}, body: {result_json}")
 
-    return result_json.get("success")
+    if resp.status_code != 200:
+        logger.info(f"GoogleRecaptcha response {g_recaptcha_response} status: {resp.status_code} failed: {result_json}")
+        return False
+
+    if result_json.get("success") is not True:
+        return False
+
+    if result_json.get("score", 0) < min_score_threshold:
+        return False
+
+    return True
