@@ -9,7 +9,7 @@ def get_decoded_jwt_token(jwt_token: str) -> dict:
     Gets a decoded JWT token.
     """
 
-    return jwt.decode(jwt_token, verify=False)
+    return jwt.decode(jwt_token, algorithms=["HS256"], options={"verify_signature": False})
 
 
 def get_bearer_authorization_token(authorization_value: str) -> Optional[str]:
