@@ -5,15 +5,16 @@ from unittest import mock
 
 import pytest
 from django.test import TestCase
+from requests.exceptions import HTTPError
+from requests_mock import Mocker
+from rest_framework.exceptions import APIException
+from rest_framework.viewsets import ViewSet
+
 from jsm_user_services.drf_tools.permissions import GoogleRecaptchaPermission
 from jsm_user_services.drf_tools.permissions import IsUserAllowedToPermission
 from jsm_user_services.drf_tools.permissions import RoleBasedPermission
 from jsm_user_services.drf_tools.permissions import StatusBasedPermission
 from jsm_user_services.exception import IncorrectTypePermissionConfiguration
-from requests.exceptions import HTTPError
-from requests_mock import Mocker
-from rest_framework.exceptions import APIException
-from rest_framework.viewsets import ViewSet
 
 
 class TestDRFPermissionClasses(TestCase):
@@ -426,7 +427,9 @@ class TestDRFPermissionClasses(TestCase):
 
         with Mocker(real_http=True) as mocker:
             mocked_request = mocker.post(
-                "https://www.google.com/recaptcha/api/siteverify", status_code=200, json={"success": True},
+                "https://www.google.com/recaptcha/api/siteverify",
+                status_code=200,
+                json={"success": True, "score": 0.8},
             )
 
             assert self.google_permission_recaptcha.has_permission(request, None)
@@ -442,7 +445,9 @@ class TestDRFPermissionClasses(TestCase):
 
         with Mocker(real_http=True) as mocker:
             mocked_request = mocker.post(
-                "https://www.google.com/recaptcha/api/siteverify", status_code=200, json={"success": False},
+                "https://www.google.com/recaptcha/api/siteverify",
+                status_code=200,
+                json={"success": False},
             )
 
             assert not self.google_permission_recaptcha.has_permission(request, None)
@@ -463,7 +468,9 @@ class TestDRFPermissionClasses(TestCase):
         with Mocker(real_http=True) as mocker:
             with pytest.raises(TestException):
                 mocked_request = mocker.post(
-                    "https://www.google.com/recaptcha/api/siteverify", status_code=200, json={"success": False},
+                    "https://www.google.com/recaptcha/api/siteverify",
+                    status_code=200,
+                    json={"success": False},
                 )
 
                 google_permission_with_api_exception.has_permission(request, None)
@@ -484,7 +491,9 @@ class TestDRFPermissionClasses(TestCase):
         with Mocker(real_http=True) as mocker:
             with pytest.raises(TestException):
                 mocked_request = mocker.post(
-                    "https://www.google.com/recaptcha/api/siteverify", status_code=200, json={"success": False},
+                    "https://www.google.com/recaptcha/api/siteverify",
+                    status_code=200,
+                    json={"success": False},
                 )
 
                 google_permission_with_api_exception.has_permission(request, None)
@@ -505,7 +514,9 @@ class TestDRFPermissionClasses(TestCase):
 
         with Mocker(real_http=True) as mocker:
             mocked_request = mocker.post(
-                "https://www.google.com/recaptcha/api/siteverify", status_code=200, json={"success": False},
+                "https://www.google.com/recaptcha/api/siteverify",
+                status_code=200,
+                json={"success": False},
             )
 
             assert not google_permission_with_another_exception.has_permission(request, None)
@@ -528,7 +539,9 @@ class TestDRFPermissionClasses(TestCase):
 
         with Mocker(real_http=True) as mocker:
             mocked_request = mocker.post(
-                "https://www.google.com/recaptcha/api/siteverify", status_code=200, json={"success": False},
+                "https://www.google.com/recaptcha/api/siteverify",
+                status_code=200,
+                json={"success": False},
             )
 
             assert not google_permission_with_another_exception.has_permission(request, None)
@@ -553,3 +566,21 @@ class TestDRFPermissionClasses(TestCase):
 
         fake_view_set = FakeViewSet()
         assert fake_view_set.get_permissions() == [permission]
+
+    def test_permission_class_should_fail_if_google_verification_score_is_less_than_default(self):
+
+        request = mock.MagicMock()
+        request.headers = {}
+        request.data = {
+            "g_recaptcha_response": "some cool value",
+        }
+
+        with Mocker(real_http=True) as mocker:
+            mocked_request = mocker.post(
+                "https://www.google.com/recaptcha/api/siteverify",
+                status_code=200,
+                json={"success": True, "score": 0.7},
+            )
+
+            assert self.google_permission_recaptcha.has_permission(request, None) is False
+            assert mocked_request.called
